<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "רעדאַגירן Form רעסיפּיענץ");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "רעדאַגירן Form רעסיפּיענץ");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "פאָרעם בלאַט");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "איר מייַ שטעלן מער ווי איין באַקומער דורך סעפּערייטינג די ימיילז מיט קאָמעס.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "זייגער באַקומער ...");
define('VIEW_FORM_TABLES_HEADING', "View פאָרם טאַבלעס");
define('VIEW_FORM_TABLES_BTN', "View פאָרם טאַבלעס");
define('VIEW_FORM_TABLES_SELECT_TABLE', "סעלעקטירן אַ טאַבלעס צו View");
define('VIEW_FORM_TABLES_FILTER_READ', "פֿילטריר לייענען אַרטיקלען");
?>